#
# spec file for package fake-gcs-server
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
%global provider_prefix github.com/fsouza/fake-gcs-server/fakestorage
%global import_path     %{provider_prefix}
Name:           fake-gcs-server
Version:        1.49.2
Release:        1.3
Summary:        Google Cloud Storage emulator & testing library
License:        BSD-2-Clause
URL:            https://github.com/fsouza/fake-gcs-server
Source0:        https://github.com/fsouza/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  fdupes
BuildRequires:  golang-packaging
BuildRequires:  xz
%{go_nostrip}
%{go_provides}

%description
fake-gcs-server provides an emulator for Google Cloud Storage API. It can be used as a library in Go projects and/or as a standalone binary/Docker image.

%prep
%autosetup -p1 -a1

%build
%goprep %{import_path}
go build

%install
%goinstall
install -Dm755 fake-gcs-server %{buildroot}%{_bindir}/fake-gcs-server
%gosrc

%fdupes %{buildroot}%{_datadir}/go

%{gofilelist}

%check
%gotest %{import_path}

%files -f file.lst
%license LICENSE
%doc README.md
%{_bindir}/fake-gcs-server

%changelog
* Thu Jul 18 2024 Matej Cepl <mcepl@cepl.eu>
- Update to v1.49.2:
  - Add omitempty to new timestorageclassupdated
- Update to v1.49.1:
  - examples: remove Ruby
  - Include fields required by alpakka scala client in response
  - Add Testcontainers example with Node.js
- Update to v1.49.0:
  - Add Object Deletion Using Signed URLs
  - examples/node: add exists()
  - Don't omit versioning.enabled in bucket response
  - Additional ACL response attributes
  - Additional bucket response attributes
- Update to v1.48.0:
  - Fix brittle test
  - Fill the errors attribute for HTTP errors
  - Remove unnecessary quoting around ETag in JSON response
  - Additional object response attributes
  - Support the projection parameter in getObject
- Update to v1.47.8:
  - Add Ruby example
- Update to v1.47.7:
  - Updated python example
  - Fixed patchObject ignoring ContentType and ContentEncoding
- Update to v1.47.6:
  - ci/goreleaser: remove deprecated option
  - config: trim trailing slashes from externalURL
- Update to v1.47.5:
  - Migrate from logrus to slog
  - add missing etag header in download object response
  - github/workflows/main: pin python to 3.11 in gsutil example
  - github/workflows/main: bump node and java in examples
- Update to v1.47.4:
  - server: add MethodHead to the /download mapping
- Update to v1.47.2:
  - backend/fs: return empty BucketAttrs if the metadata file is
    missing
- Update to v1.47.1:
  - Restore 4443 as default port for '-scheme http' as before PR
    [#1215]
- Update to v1.47.0:
  - Disallow composing more than 32 objects at once
  - Remove obsolete upload route
  - Additional bucket response attributes
  - Support trailing slash in /o and /b routes
  - Add scheme option to bind to both HTTP and HTTPS
- Update to v1.46.0:
  - Unify logic for seeding the server from a directory
  - Send X-Goog-Stored-Content-Encoding header
  - Omit items if empty in object list response
  - Add Bucket Attributes
  - backend/fs: some bucket attributes cleanup
* Mon Jul 17 2023 Matej Cepl <mcepl@suse.com>
- Use %%autosetup.
- Put packaging files under the control of git.
* Wed Jul 12 2023 Matej Cepl <mcepl@suse.com>
- Update to 1.45.2:
    (just the changelog for the last release, there are many
    releases between 1.45.2 and 1.32.2, which cannot be recorded
    here).
  - github/workflows: try remote docker cache by @fsouza in #1161
  - multipart uploads: Hack to support gsutil cp by @ekimekim in #1182
  - Add bucket filter for notification events by @mccalltd in #1167
  - examples: add example with gsutil by @fsouza in #1183
  - internal/config: always have an externalURL by @fsouza in #1184
- Add _service file with proper generation of vendor.tar.xz file.
- clean up SPEC file.
* Fri Dec 31 2021 Matej Cepl <mcepl@suse.com>
- Initial packaging of fake-gcs-server 1.32.2
